==> nextcloud-16.0.5.tgz: nextcloud/apps/files_external/l10n/he.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "התקני אחסון חיצוניים",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Grant access" : "הענקת גישה",
    "Error configuring OAuth1" : "שגיאה בתצורת OAuth1",
    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
    "Error configuring OAuth2" : "שגיאה בתצורת OAuth2",
    "Generate keys" : "יצירת מפתחות",
    "Error generating key pair" : "שגיאה ביצירת זוג מפתחות",
    "All users. Type to select user or group." : "כל המשתמשים. יש להקיש לבחירת משתמש או קבוצה.",
    "(group)" : "(קבוצה)",
    "Compatibility with Mac NFD encoding (slow)" : "תואם של קידוד Mac NFD (איטי)",
    "Enable encryption" : "אפשר הצפנה",
    "Enable previews" : "מאפשר תצוגות מקדימות",
    "Enable sharing" : "הפעלת שיתוף",
    "Check for changes" : "בדיקה אחר שינויים",
    "Never" : "לעולם לא",
    "Once every direct access" : "פעם אחת כל כניסה ישירה",
    "Read only" : "קריאה בלבד",
    "Delete" : "מחיקה",
    "Admin defined" : "הוגדר מנהל",
    "Are you sure you want to delete this external storage?" : "למחוק את האחסון החיצוני הזה?",
    "Delete storage?" : "למחוק אחסון?",
    "Saved" : "נשמר",
    "Saving..." : "מתבצעת שמירה…",
    "Save" : "שמירה",
    "Empty response from the server" : "תגובה ריקה מהשרת",
    "Couldn't access. Please log out and in again to activate this mount point" : "לא ניתן לגשת. נא לצאת ולהיכנס שוב כדי להפעיל את נקודת העגינה הזו",
    "Couldn't get the information from the remote server: {code} {type}" : "לא ניתן לקבל את המידע מהשרת המרוחק: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "לא ניתן היה לקבל את רשימת נקודות העיגון החיצוניות: {type}",
    "There was an error with message: " : "התרחשה שגיאה עם הודעה: ",
    "External mount error" : "שגיאת עגינה חיצונית",
    "external-storage" : "אחסון חיצוני",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "לא ניתן לקבל את רשימת נקודות העגינה לכונני רשת ב־Windows: תגובה ריקה מהשרת",
    "Please enter the credentials for the {mount} mount" : "יש להזין את פרטי הגישה עבור התקן עגינה {mount}",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Credentials saved" : "פרטי גישה נשמרו",
    "Credentials saving failed" : "שמירת פרטי גישה נכשלה",
    "Credentials required" : "נדרשים פרטי גישה",
    "Storage with ID \"%d\" not found" : "לא נמצא התקן אחסון עם המזהה „%d”",
    "Invalid backend or authentication mechanism class" : "צד אחורי או סוג מנגנון אימות לא חוקי",
    "Invalid mount point" : "נקודת עגינה לא חוקית",
    "Objectstore forbidden" : "Objectstore חסום",
    "Invalid storage backend \"%s\"" : "צד אחורי של האחסון אינו תקין \"%s\"",
    "Not permitted to use backend \"%s\"" : "השימוש בצד אחורי \"%s\" אינו מותר",
    "Not permitted to use authentication mechanism \"%s\"" : "השימוש במכניזם אימות \"%s\" אינו מותר",
    "Unsatisfied backend parameters" : "פרמטרים צד אחורי אינם מספקים",
    "Unsatisfied authentication mechanism parameters" : "פרמטרים של מכניזם אימות אינם מספקים",
    "Insufficient data: %s" : "מידע לא מספק: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "למשתמשים אין אפשרות לערוך התקן אחסון עם מזהה „%d”",
    "Access key" : "מפתח כניסה",
    "Secret key" : "מפתח סודי",
    "Builtin" : "מובנה",
    "None" : "כלום",
    "OAuth1" : "OAuth1",
    "App key" : "מפתח יישום",
    "App secret" : "סוד יישום",
    "OAuth2" : "OAuth2",
    "Client ID" : "זיהוי לקוח",
    "Client secret" : "סוד לקוח",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "שם דייר",
    "Identity endpoint URL" : "זהות נתיב נקודת קצה",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "שם תחום",
    "Rackspace" : "חץ אחורה",
    "API key" : "מפתח API",
    "Global credentials" : "פרטי גישה גלובליים",
    "Log-in credentials, save in database" : "פרטי כניסה, שמירה במסד הנתונים",
    "Username and password" : "שם משתמש וסיסמא",
    "Log-in credentials, save in session" : "אישורי התחברות, נשמרים במידע שיחה - סשן",
    "User entered, store in database" : "הוכנס על ידי המשתמש, אחסון במסד הנתונים",
    "RSA public key" : "מפתח ציבורי RSA",
    "Public key" : "מפתח ציבורי",
    "RSA private key" : "מפתח RSA פרט",
    "Private key" : "מפתח פרט",
    "Kerberos ticket" : "כרטיס Kerberos",
    "Amazon S3" : "אמזון S3",
    "Bucket" : "סל",
    "Hostname" : "שם מארח",
    "Port" : "שער",
    "Region" : "אזור",
    "Enable SSL" : "הפעלת SSL",
    "Enable Path Style" : "אהפעלת סגנון נתיב",
    "Legacy (v2) authentication" : "אימות מיושן (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "נתיב אינטרנט",
    "Remote subfolder" : "תיקיית משנה רחוקה",
    "Secure https://" : "פרוטוקול מאובטח https://",
    "FTP" : "FTP",
    "Host" : "מארח",
    "Secure ftps://" : "פרוטוקול מאובטח ftps://",
    "Local" : "מקומי",
    "Location" : "מיקום",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "נתיב ראשי",
    "SFTP with secret key login" : "SFTP עם מפתח כניסה סודי",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "שיתוף",
    "SMB / CIFS using OC login" : "SMB / CIFS בשימוש עם כניסת OC",
    "Username as share" : "שם משתמש כשיתוף",
    "OpenStack Object Storage" : "אחסון אובייקט OpenStack",
    "Service name" : "שם שירות",
    "Request timeout (seconds)" : "פסק זמן מבוקש (שניות)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "התמיכה של cURL ב־PHP אינה מופעלת או מותקנת. אין אפשרות לעגן את %s. נא לבקש ממנהל המערכת שלך להתקין אותה.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "התמיכה של FTP ב־PHP אינה מופעלת או מותקנת. אין אפשרות לעגן את %s. נא לבקש ממנהל המערכת שלך להתקין אותה.",
    "External storage support" : "תמיכה באחסון חיצוני",
    "Adds basic external storage support" : "מוסיף תמיכה באחסון חיצוני בסיסי",
    "No external storage configured or you don't have the permission to configure them" : "לא הוגדר התקן חיצוני או שאין לך הרשאות להגדיר כאלה",
    "Name" : "שם",
    "Storage type" : "סוג אחסון",
    "Scope" : "היקף",
    "Folder name" : "שם התיקייה",
    "External storage" : "אחסון חיצוני",
    "Authentication" : "אימות",
    "Configuration" : "הגדרות",
    "Available for" : "זמין עבור",
    "Click to recheck the configuration" : "יש ללחוץ כאן כדי לבדוק את ההגדרות מחדש",
    "Add storage" : "הוספת אחסון",
    "Advanced settings" : "הגדרות מתקדמות",
    "Allow users to mount external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-18.0.2.tgz: nextcloud/apps/files_external/l10n/he.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "התקני אחסון חיצוניים",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Grant access" : "הענקת גישה",
    "Error configuring OAuth1" : "שגיאה בתצורת OAuth1",
    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
    "Error configuring OAuth2" : "שגיאה בתצורת OAuth2",
    "Generate keys" : "יצירת מפתחות",
    "Error generating key pair" : "שגיאה ביצירת זוג מפתחות",
    "All users. Type to select user or group." : "כל המשתמשים. יש להקיש לבחירת משתמש או קבוצה.",
    "(group)" : "(קבוצה)",
    "Compatibility with Mac NFD encoding (slow)" : "תואם של קידוד Mac NFD (איטי)",
    "Enable encryption" : "אפשר הצפנה",
    "Enable previews" : "מאפשר תצוגות מקדימות",
    "Enable sharing" : "הפעלת שיתוף",
    "Check for changes" : "בדיקה אחר שינויים",
    "Never" : "לעולם לא",
    "Once every direct access" : "פעם אחת כל כניסה ישירה",
    "Read only" : "קריאה בלבד",
    "Delete" : "מחיקה",
    "Admin defined" : "הוגדר מנהל",
    "Are you sure you want to delete this external storage?" : "למחוק את האחסון החיצוני הזה?",
    "Delete storage?" : "למחוק אחסון?",
    "Saved" : "נשמר",
    "Saving …" : "מתבצעת שמירה…",
    "Save" : "שמירה",
    "Empty response from the server" : "תגובה ריקה מהשרת",
    "Couldn't access. Please log out and in again to activate this mount point" : "לא ניתן לגשת. נא לצאת ולהיכנס שוב כדי להפעיל את נקודת העגינה הזו",
    "Couldn't get the information from the remote server: {code} {type}" : "לא ניתן לקבל את המידע מהשרת המרוחק: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "לא ניתן היה לקבל את רשימת נקודות העיגון החיצוניות: {type}",
    "There was an error with message: " : "התרחשה שגיאה עם הודעה: ",
    "External mount error" : "שגיאת עגינה חיצונית",
    "external-storage" : "אחסון חיצוני",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "לא ניתן לקבל את רשימת נקודות העגינה לכונני רשת ב־Windows: תגובה ריקה מהשרת",
    "Please enter the credentials for the {mount} mount" : "יש להזין את פרטי הגישה עבור התקן עגינה {mount}",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Credentials saved" : "פרטי גישה נשמרו",
    "Credentials saving failed" : "שמירת פרטי גישה נכשלה",
    "Credentials required" : "נדרשים פרטי גישה",
    "Storage with ID \"%d\" not found" : "לא נמצא התקן אחסון עם המזהה „%d”",
    "Invalid backend or authentication mechanism class" : "צד אחורי או סוג מנגנון אימות לא חוקי",
    "Invalid mount point" : "נקודת עגינה לא חוקית",
    "Objectstore forbidden" : "Objectstore חסום",
    "Invalid storage backend \"%s\"" : "צד אחורי של האחסון אינו תקין \"%s\"",
    "Not permitted to use backend \"%s\"" : "השימוש בצד אחורי \"%s\" אינו מותר",
    "Not permitted to use authentication mechanism \"%s\"" : "השימוש במכניזם אימות \"%s\" אינו מותר",
    "Unsatisfied backend parameters" : "פרמטרים צד אחורי אינם מספקים",
    "Unsatisfied authentication mechanism parameters" : "פרמטרים של מכניזם אימות אינם מספקים",
    "Insufficient data: %s" : "מידע לא מספק: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "למשתמשים אין אפשרות לערוך התקן אחסון עם מזהה „%d”",
    "Access key" : "מפתח כניסה",
    "Secret key" : "מפתח סודי",
    "Builtin" : "מובנה",
    "None" : "כלום",
    "OAuth1" : "OAuth1",
    "App key" : "מפתח יישום",
    "App secret" : "סוד יישום",
    "OAuth2" : "OAuth2",
    "Client ID" : "זיהוי לקוח",
    "Client secret" : "סוד לקוח",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "שם דייר",
    "Identity endpoint URL" : "זהות נתיב נקודת קצה",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "שם תחום",
    "Rackspace" : "חץ אחורה",
    "API key" : "מפתח API",
    "Global credentials" : "פרטי גישה גלובליים",
    "Log-in credentials, save in database" : "פרטי כניסה, שמירה במסד הנתונים",
    "Username and password" : "שם משתמש וסיסמא",
    "Log-in credentials, save in session" : "אישורי התחברות, נשמרים במידע שיחה - סשן",
    "Global credentials, user entered" : "פרטי גישה גלובליים, מולאו על ידי המשתמש",
    "User entered, store in database" : "הוכנס על ידי המשתמש, אחסון במסד הנתונים",
    "RSA public key" : "מפתח ציבורי RSA",
    "Public key" : "מפתח ציבורי",
    "RSA private key" : "מפתח RSA פרט",
    "Private key" : "מפתח פרט",
    "Kerberos ticket" : "כרטיס Kerberos",
    "Amazon S3" : "אמזון S3",
    "Bucket" : "סל",
    "Hostname" : "שם מארח",
    "Port" : "שער",
    "Region" : "אזור",
    "Enable SSL" : "הפעלת SSL",
    "Enable Path Style" : "אהפעלת סגנון נתיב",
    "Legacy (v2) authentication" : "אימות מיושן (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "נתיב אינטרנט",
    "Remote subfolder" : "תיקיית משנה רחוקה",
    "Secure https://" : "פרוטוקול מאובטח https://",
    "FTP" : "FTP",
    "Host" : "מארח",
    "Secure ftps://" : "פרוטוקול מאובטח ftps://",
    "Local" : "מקומי",
    "Location" : "מיקום",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "נתיב ראשי",
    "SFTP with secret key login" : "SFTP עם מפתח כניסה סודי",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "שיתוף",
    "Show hidden files" : "הצגת קבצים נסתרים",
    "Timeout" : "פג הזמן הקצוב",
    "SMB / CIFS using OC login" : "SMB / CIFS בשימוש עם כניסת OC",
    "Username as share" : "שם משתמש כשיתוף",
    "OpenStack Object Storage" : "אחסון אובייקט OpenStack",
    "Service name" : "שם שירות",
    "Request timeout (seconds)" : "פסק זמן מבוקש (שניות)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "התמיכה של cURL ב־PHP אינה מופעלת או מותקנת. אין אפשרות לעגן את %s. נא לבקש ממנהל המערכת שלך להתקין אותה.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "התמיכה של FTP ב־PHP אינה מופעלת או מותקנת. אין אפשרות לעגן את %s. נא לבקש ממנהל המערכת שלך להתקין אותה.",
    "External storage support" : "תמיכה באחסון חיצוני",
    "Adds basic external storage support" : "מוסיף תמיכה באחסון חיצוני בסיסי",
    "No external storage configured or you don't have the permission to configure them" : "לא הוגדר התקן חיצוני או שאין לך הרשאות להגדיר כאלה",
    "Name" : "שם",
    "Storage type" : "סוג אחסון",
    "Scope" : "היקף",
    "Open documentation" : "פתיחת תיעוד",
    "Folder name" : "שם התיקייה",
    "External storage" : "אחסון חיצוני",
    "Authentication" : "אימות",
    "Configuration" : "הגדרות",
    "Available for" : "זמין עבור",
    "Click to recheck the configuration" : "יש ללחוץ כאן כדי לבדוק את ההגדרות מחדש",
    "Add storage" : "הוספת אחסון",
    "Advanced settings" : "הגדרות מתקדמות",
    "Allow users to mount external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני",
    "Saving..." : "מתבצעת שמירה…"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
